<?php

namespace Testpackageprovider\Test\Http\Controllers;

use App\Http\Controllers\UserController as UserController;
use Form;
use Testpackageprovider\Test\Http\Requests\TestarticlesUserRequest;
use Testpackageprovider\Test\Interfaces\TestarticlesRepositoryInterface;
use Testpackageprovider\Test\Models\Testarticles;

class TestarticlesUserController extends UserController
{
    /**
     * Initialize testarticles controller.
     *
     * @param type TestarticlesRepositoryInterface $testarticles
     *
     * @return type
     */
    public function __construct(TestarticlesRepositoryInterface $testarticles)
    {
        $this->repository = $testarticles;
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(TestarticlesUserRequest $request)
    {
        $this->repository->pushCriteria(new \Lavalite\Test\Repositories\Criteria\TestarticlesUserCriteria());
        $testarticles = $this->repository->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();

        $this->theme->prependTitle(trans('test::testarticles.names').' :: ');

        return $this->theme->of('test::user.testarticles.index', compact('testarticles'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param Testarticles $testarticles
     *
     * @return Response
     */
    public function show(TestarticlesUserRequest $request, Testarticles $testarticles)
    {
        Form::populate($testarticles);

        return $this->theme->of('test::user.testarticles.show', compact('testarticles'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(TestarticlesUserRequest $request)
    {

        $testarticles = $this->repository->newInstance([]);
        Form::populate($testarticles);

        return $this->theme->of('test::user.testarticles.create', compact('testarticles'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(TestarticlesUserRequest $request)
    {
        try {
            $attributes = $request->all();
            $attributes['user_id'] = user_id();
            $testarticles = $this->repository->create($attributes);

            $this->responseCode = 201;
            $this->responseMessage = trans('messages.success.created', ['Module' => trans('test::testarticles.name')]);
            $this->responseRedirect = trans_url('/user/test/testarticles');
            return $this -> respond($request);
        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param Testarticles $testarticles
     *
     * @return Response
     */
    public function edit(TestarticlesUserRequest $request, Testarticles $testarticles)
    {

        Form::populate($testarticles);

        return $this->theme->of('test::user.testarticles.edit', compact('testarticles'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param Testarticles $testarticles
     *
     * @return Response
     */
    public function update(TestarticlesUserRequest $request, Testarticles $testarticles)
    {
        try {
            $this->repository->update($request->all(), $testarticles->getRouteKey());
            $this->responseCode = 204;
            $this->responseMessage = trans('messages.success.updated', ['Module' => trans('test::testarticles.name')]);
            $this->responseRedirect = trans_url('/user/test/testarticles');
            return $this -> respond($request);
        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(TestarticlesUserRequest $request, Testarticles $testarticles)
    {
        try {
            $this->repository->delete($testarticles->getRouteKey());
            $this->responseCode = 204;
            $this->responseMessage = trans('messages.success.deleted', ['Module' => trans('test::testarticles.name')]);
            $this->responseRedirect = trans_url('/user/test/testarticles');
            return $this -> respond($request);
        } catch (Exception $e) {

            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);

        }
    }
}
